package com.vctgo.system.service;

import java.util.List;

import com.vctgo.system.domain.SysTeachWorkExperience;
import com.baomidou.mybatisplus.core.metadata.IPage;

/**
 * 幼儿园职工与工作经历关联Service接口
 *
 * @author caesar
 * @date 2024-03-27
 */
public interface ISysTeachWorkExperienceService {
    /**
     * 查询幼儿园职工与工作经历关联
     *
     * @param id 幼儿园职工与工作经历关联主键
     * @return 幼儿园职工与工作经历关联
     */
    SysTeachWorkExperience selectSysTeachWorkExperienceById(Long id);

    /**
     * 查询幼儿园职工与工作经历关联列表-分页
     *
     * @param sysTeachWorkExperience 幼儿园职工与工作经历关联
     * @return 幼儿园职工与工作经历关联集合
     */
    IPage<SysTeachWorkExperience> selectSysTeachWorkExperiencePage(SysTeachWorkExperience sysTeachWorkExperience);

    /**
     * 查询幼儿园职工与工作经历关联列表
     *
     * @param sysTeachWorkExperience 幼儿园职工与工作经历关联
     * @return 幼儿园职工与工作经历关联集合
     */
    List<SysTeachWorkExperience> selectSysTeachWorkExperienceList(SysTeachWorkExperience sysTeachWorkExperience);

    /**
     * 新增幼儿园职工与工作经历关联
     *
     * @param sysTeachWorkExperience 幼儿园职工与工作经历关联
     * @return 结果
     */
    int insertSysTeachWorkExperience(SysTeachWorkExperience sysTeachWorkExperience);

    /**
     * 修改幼儿园职工与工作经历关联
     *
     * @param sysTeachWorkExperience 幼儿园职工与工作经历关联
     * @return 结果
     */
    int updateSysTeachWorkExperience(SysTeachWorkExperience sysTeachWorkExperience);

    /**
     * 逻辑删除幼儿园职工与工作经历关联
     *
     * @param ids
     * @return 结果
     */
    int logicalDeleteSysTeachWorkExperienceByIds(Long[] ids);

    /**
     * 批量删除幼儿园职工与工作经历关联
     *
     * @param ids 需要删除的幼儿园职工与工作经历关联主键集合
     * @return 结果
     */
    int deleteSysTeachWorkExperienceByIds(Long[] ids);

    /**
     * 删除幼儿园职工与工作经历关联信息
     *
     * @param id 幼儿园职工与工作经历关联主键
     * @return 结果
     */
    int deleteSysTeachWorkExperienceById(Long id);
}
